@@ -5,7 +5,7 @@ use Moo 1.003;
 use Search::Elasticsearch::Util qw(parse_params load_plugin);
 use namespace::clean;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 my %Default_Plugins = (
     client      => [ 'Search::Elasticsearch::Client',       'Direct' ],
@@ -53,7 +53,7 @@ Search::Elasticsearch - The official client for Elasticsearch
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -174,8 +174,8 @@ Full support for all Elasticsearch APIs
 
 =item *
 
-HTTP backend (currently synchronous only - L<Any::Event> support will be added
-later)
+HTTP backend (for an async backend using L<Promises>, see
+L<Search::Elasticsearch::Async>)
 
 =item *
 
@@ -475,7 +475,13 @@ bodies.  See:
 
 =over
 
-=item * L<Search::Elasticsearch::Serializer::JSON>
+=item * L<Search::Elasticsearch::Serializer::JSON> (default)
+
+=item * L<Search::Elasticsearch::Serializer::JSON::Cpanel>
+
+=item * L<Search::Elasticsearch::Serializer::JSON::XS>
+
+=item * L<Search::Elasticsearch::Serializer::JSON::PP>
 
 =back
 
@@ -566,16 +572,6 @@ L<Search::Elasticsearch::Scroll>.  These helper classes are accessible as:
     $bulk   = $e->bulk_helper( %args_to_new );
     $scroll = $e->scroll_helper( %args_to_new );
 
-=head1 TODO
-
-=over
-
-=item * Async support
-
-Add async support using L<Promises> for L<AnyEvent> and perhaps L<Mojo>.
-
-=back
-
 =head1 BUGS
 
 This is a stable API but this implementation is new. Watch this space
