@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Bulk;
-$Search::Elasticsearch::Bulk::VERSION = '1.10';
+$Search::Elasticsearch::Bulk::VERSION = '1.11';
 use Moo;
 with 'Search::Elasticsearch::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Sync';
@@ -52,8 +52,7 @@ sub flush {
     catch {
         my $error = $_;
         $self->clear_buffer
-            if $error->is('Request')
-            and not $error->is('Unavailable');
+            unless $error->is('Cxn');
 
         die $error;
     };
@@ -108,16 +107,14 @@ Search::Elasticsearch::Bulk - A helper module for the Bulk API and for reindexin
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
     use Search::Elasticsearch;
-    use Search::Elasticsearch::Bulk;
 
     my $es   = Search::Elasticsearch->new;
-    my $bulk = Search::Elasticsearch::Bulk->new(
-        es      => $es,
+    my $bulk = $es->bulk_helper(
         index   => 'my_index',
         type    => 'my_type'
     );
@@ -144,8 +141,7 @@ version 1.10
     $bulk->flush
 
     # Reindex docs:
-    $bulk = Search::Elasticsearch::Bulk->new(
-        es      => $es,
+    my $bulk = $es->bulk_helper(
         index   => 'new_index',
         verbose => 1
     );
@@ -173,8 +169,7 @@ L<Search::Elasticsearch::Role::Is_Sync>.
 
 =head2 C<new()>
 
-    $bulk = Search::Elasticsearch::Bulk->new(
-        es          => $es,                 # required
+    my $bulk = $es->bulk_helper(
 
         index       => 'default_index',     # optional
         type        => 'default_type',      # optional
@@ -235,22 +230,16 @@ to C<1_000,000> bytes.
 
 =head2 Errors when flushing
 
-There are three levels of error which can be thrown when L</flush()>
+There are two types of error which can be thrown when L</flush()>
 is called, either manually or automatically.
 
 =over
 
 =item * Temporary Elasticsearch errors
 
-For instance, a C<NoNodes> error which indicates that your cluster is down.
+A C<Cxn> error like a C<NoNodes> error which indicates that your cluster is down.
 These errors do not clear the buffer, as they can be retried later on.
 
-=item * Request errors
-
-For instance, if one of your actions is malformed (eg you are missing
-a required parameter like C<index>) then the whole L</flush()> request is
-aborted and the buffer is cleared of all actions.
-
 =item * Action errors
 
 Individual actions may fail. For instance, a C<create> action will fail
@@ -286,8 +275,7 @@ will have C<$i> set to C<0>, the second will have C<$i> set to C<1> etc.
 
 =head3 C<on_success>
 
-    $bulk = Search::Elasticsearch->new(
-        es          => $es,
+    my $bulk = $es->bulk_helper(
         on_success  => sub {
             my ($action,$response,$i) = @_;
             # do something
@@ -299,8 +287,7 @@ response.
 
 =head3 C<on_conflict>
 
-    $bulk = Search::Elasticsearch::Bulk->new(
-        es           => $es,
+    my $bulk = $es->bulk_helper(
         on_conflict  => sub {
             my ($action,$response,$i,$version) = @_;
             # do something
@@ -314,8 +301,7 @@ of the document currently stored in Elasticsearch (if found).
 
 =head3 C<on_error>
 
-    $bulk = Search::Elasticsearch::Bulk->new(
-        es        => $es,
+    my $bulk = $es->bulk_helper(
         on_error  => sub {
             my ($action,$response,$i) = @_;
             # do something
@@ -331,8 +317,7 @@ If you want to be in control of flushing, and you just want to receive
 the raw response that Elasticsearch sends instead of using callbacks,
 then you can do so as follows:
 
-    $bulk = Search::Elasticsearch::Bulk->new(
-        es          => $es,
+    my $bulk = $es->bulk_helper(
         max_count   => 0,
         max_size    => 0,
         on_error    => undef
@@ -472,7 +457,7 @@ the source for the documents which are to be reindexed.
 If the C<source> argument is a HASH ref, then the hash is passed to
 L<Search::Elasticsearch::Scroll/new()> to create a new scrolled search.
 
-    $bulk = Search::Elasticsearch::Bulk->new(
+    my $bulk = $es->bulk_helper(
         index   => 'new_index',
         verbose => 1
     );
@@ -533,8 +518,7 @@ another, you can use two separate C<$es> objects:
     $es_target  = Search::Elasticsearch->new( nodes => 'localhost:9200' );
     $es_source  = Search::Elasticsearch->new( nodes => 'search1:9200' );
 
-    Search::Elasticsearch::Bulk->new(
-        es      => $es_target,
+    my $bulk = $es_targer->bulk_helper(
         verbose => 1
     )
     -> reindex(
