@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::Direct;
-$Search::Elasticsearch::Client::Direct::VERSION = '1.10';
+$Search::Elasticsearch::Client::Direct::VERSION = '1.11';
 use Moo;
 with 'Search::Elasticsearch::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -116,7 +116,7 @@ Search::Elasticsearch::Client::Direct - Thin client with full support for Elasti
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -945,6 +945,45 @@ Query string parameters:
 See the L<count docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-count.html>
 for more information.
 
+=head2 C<search_template()>
+
+    $results = $e->search_template(
+        index   => 'index' | \@indices,     # optional
+        type    => 'type'  | \@types,       # optional
+
+        body    => { search params }        # optional
+    );
+
+Perform a search by specifying a template (either predefined or defined
+within the C<body>) and parameters to use with the template, eg:
+
+    $results = $e->search_template(
+        template => {
+            query => {
+                match => {
+                    "{{my_field}}" => "{{my_value}}"
+                }
+            },
+            size => "{{my_size}}"
+        },
+        params => {
+            my_field => 'foo',
+            my_value => 'bar',
+            my_size  => 5
+        }
+    );
+
+See the L<search template docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-template.html>
+for more information.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>,
+    C<preference>,
+    C<scroll>,
+    C<search_type>
+
 =head2 C<scroll()>
 
     $results = $e->scroll(
@@ -978,6 +1017,12 @@ for more information.
         scroll_id => $id | \@ids    # required
     );
 
+Or
+
+    $response = $e->clear_scroll(
+        body => $id
+    );
+
 The C<clear_scroll()> method can clear unfinished scroll requests, freeing
 up resources on the server.
 
@@ -1258,6 +1303,68 @@ Query string parameters:
 See the L<mlt docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-more-like-this.html>
 for more information.
 
+=head1 BENCHMARK METHODS
+
+=head2 C<benchmark()>
+
+    $results = $e->benchamrk(
+        index   => 'index' | \@indices,     # optional
+        type    => 'type'  | \@types,       # optional
+
+        body    => { search params }        # optional
+    );
+
+Run a search benchmark comparing query variations or the performance of
+different index settings, eg:
+
+    $results = $e->benchmark(
+        index => 'test_index',
+        type  => 'test_type',
+        body  => {
+            name        => 'test_query',
+            competitors => [
+                {
+                    name => 'term_query',
+                    requests =>[
+                        { query => { term => { my_field => 'bar' }}}
+                    ]
+                },
+                {
+                    name => 'match_query',
+                    requests =>[
+                        { query => { match => { my_field => 'bar' }}}
+                    ]
+                },
+            ]
+        }
+    );
+
+See the L<benchamrk docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-benchmark.html> for more.
+
+Query string parameters:
+    C<verbose>
+
+=head2 C<list_benchmarks()>
+
+    $results = $e->list_benchmarks(
+        index   => 'index' | \@indices,     # optional
+        type    => 'type'  | \@types,       # optional
+    )
+
+Lists any currently running benchmarks.
+
+See the L<benchamrk docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-benchmark.html> for more.
+
+=head2 L<abort_benchmark>
+
+    $response = $e->abort_benchmark(
+        name => $name                       # required
+    );
+
+Aborts the named benchmark
+
+See the L<benchamrk docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-benchmark.html> for more.
+
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
