@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::Direct::Cat;
-$Search::Elasticsearch::Client::Direct::Cat::VERSION = '1.10';
+$Search::Elasticsearch::Client::Direct::Cat::VERSION = '1.11';
 use Moo;
 with 'Search::Elasticsearch::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -28,7 +28,7 @@ Search::Elasticsearch::Client::Direct::Cat - A client for running cat debugging
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 DESCRIPTION
 
@@ -221,6 +221,22 @@ Query string parameters:
 See the L<cat pending-tasks docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cat-pending-tasks.html>
 for more information.
 
+=head2 C<plugins()>
+
+    say $e->cat->plugins();
+
+Returns information about plugins installed on each node.
+
+Query string parameters:
+    C<local>,
+    C<master_timeout>,
+    C<h>,
+    C<help>,
+    C<v>
+
+See the L<cat plugins docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cat-plugins.html>
+for more information.
+
 =head2 C<recovery()>
 
     say $e->cat->recovery(
@@ -236,7 +252,6 @@ Query string parameters:
     C<bytes>,
     C<h>,
     C<help>,
-    C<local>,
     C<master_timeout>,
     C<v>
 
