@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::Direct::Indices;
-$Search::Elasticsearch::Client::Direct::Indices::VERSION = '1.10';
+$Search::Elasticsearch::Client::Direct::Indices::VERSION = '1.11';
 use Moo;
 with 'Search::Elasticsearch::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -17,7 +17,7 @@ Search::Elasticsearch::Client::Direct::Indices - A client for running index-leve
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 DESCRIPTION
 
@@ -202,6 +202,7 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<flush>,
+    C<force>,
     C<ignore_unavailable>,
     C<max_num_segments>,
     C<only_expunge_deletes>,
@@ -711,6 +712,22 @@ Query string parameters:
 See the L<status docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-status.html>
 for more information.
 
+=head2 C<recovery()>
+
+    $result = $e->indices->recovery(
+        index   => 'index' | \@indices      # optional
+    );
+
+Provides insight into on-going shard recoveries.
+
+Query string parameters:
+    C<active_only>,
+    C<detailed>,
+    C<human>
+
+See the L<recovery docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-recovery.html>
+for more information.
+
 =head2 C<segments()>
 
     $result = $e->indices->segments(
