@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::Direct::Snapshot;
-$Search::Elasticsearch::Client::Direct::Snapshot::VERSION = '1.10';
+$Search::Elasticsearch::Client::Direct::Snapshot::VERSION = '1.11';
 use Moo;
 with 'Search::Elasticsearch::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -17,7 +17,7 @@ Search::Elasticsearch::Client::Direct::Snapshot - A client for managing snapshot
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 DESCRIPTION
 
@@ -125,7 +125,7 @@ for more information.
 
     $e->snapshot->restore(
         repository  => 'repository',              # required
-        snapshot    => 'snapshot'                 # required,
+        snapshot    => 'snapshot'                 # required
 
         body        => { what to restore }        # optional
     );
@@ -139,6 +139,21 @@ Query string parameters:
 See the L<"snapshot/restore docs"|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/modules-snapshot.html>
 for more information.
 
+=head2 C<status()>
+
+    $result = $e->snapshot->status(
+        repository  => 'repository',              # optional
+        snapshot    => 'snapshot' | \@snapshots   # optional
+    );
+
+Returns status information about the specified snapshots.
+
+Query string parameters:
+    C<master_timeout>
+
+See the L<"snapshot/restore docs"|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/modules-snapshot.html>
+for more information.
+
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
