@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::API;
-$Search::Elasticsearch::Role::API::VERSION = '1.10';
+$Search::Elasticsearch::Role::API::VERSION = '1.11';
 use Moo::Role;
 
 use Search::Elasticsearch::Util qw(throw);
@@ -22,6 +22,28 @@ sub api {
 
 #=== AUTOGEN - START ===
 
+    'abort_benchmark' => {
+        doc    => "search-benchmark",
+        method => "POST",
+        parts  => { name => {} },
+        paths  => [ [ { name => 2 }, "_bench", "abort", "{name}" ] ],
+        qs     => [],
+    },
+
+    'benchmark' => {
+        body   => {},
+        doc    => "search-benchmark",
+        method => "PUT",
+        parts  => { index => { multi => 1 }, type => {} },
+        paths  => [
+            [ { index => 0, type => 1 }, "{index}", "{type}", "_bench" ],
+            [ { type => 1 }, "_all", "{type}", "_bench" ],
+            [ { index => 0 }, "{index}", "_bench" ],
+            [ {}, "_bench" ],
+        ],
+        qs => ["verbose"],
+    },
+
     'bulk' => {
         body            => { required => 1 },
         doc             => "docs-bulk",
@@ -39,11 +61,14 @@ sub api {
     },
 
     'clear_scroll' => {
+        body   => {},
         doc    => "search-request-scroll",
         method => "DELETE",
-        parts  => { scroll_id => { multi => 1, required => 1 } },
-        paths =>
-            [ [ { scroll_id => 2 }, "_search", "scroll", "{scroll_id}" ] ],
+        parts  => { scroll_id => { multi => 1 } },
+        paths  => [
+            [ { scroll_id => 2 }, "_search", "scroll", "{scroll_id}" ],
+            [ {}, "_search", "scroll" ],
+        ],
         qs => [],
     },
 
@@ -243,6 +268,18 @@ sub api {
 
     'info' => { doc => "", parts => {}, paths => [ [ {} ] ], qs => [] },
 
+    'list_benchmarks' => {
+        doc   => "search-benchmark",
+        parts => { index => { multi => 1 }, type => {} },
+        paths => [
+            [ { index => 0, type => 1 }, "{index}", "{type}", "_bench" ],
+            [ { type => 1 }, "_all", "{type}", "_bench" ],
+            [ { index => 0 }, "{index}", "_bench" ],
+            [ {}, "_bench" ],
+        ],
+        qs => [],
+    },
+
     'mget' => {
         body            => { required => 1 },
         doc             => "docs-multi-get",
@@ -411,6 +448,27 @@ sub api {
         ],
     },
 
+    'search_template' => {
+        body  => {},
+        doc   => "search-template",
+        parts => { index => { multi => 1 }, type => { multi => 1 } },
+        paths => [
+            [   { index => 0, type => 1 }, "{index}",
+                "{type}", "_search",
+                "template",
+            ],
+            [ { type => 1 }, "_all", "{type}", "_search", "template" ],
+            [ { index => 0 }, "{index}", "_search", "template" ],
+            [ {}, "_search", "template" ],
+        ],
+        qs => [
+            "allow_no_indices",   "expand_wildcards",
+            "ignore_unavailable", "preference",
+            "routing",            "scroll",
+            "search_type",
+        ],
+    },
+
     'suggest' => {
         body   => { required => 1 },
         doc    => "search-search",
@@ -548,6 +606,13 @@ sub api {
         qs    => [ "h", "help", "local", "master_timeout", "v" ],
     },
 
+    'cat.plugins' => {
+        doc   => "cat-plugins",
+        parts => {},
+        paths => [ [ {}, "_cat", "plugins" ] ],
+        qs    => [ "h", "help", "local", "master_timeout", "v" ],
+    },
+
     'cat.recovery' => {
         doc   => "cat-recovery",
         parts => { index => { multi => 1 } },
@@ -555,7 +620,7 @@ sub api {
             [ { index => 2 }, "_cat", "recovery", "{index}" ],
             [ {}, "_cat", "recovery" ],
         ],
-        qs => [ "bytes", "h", "help", "local", "master_timeout", "v" ],
+        qs => [ "bytes", "h", "help", "master_timeout", "v" ],
     },
 
     'cat.shards' => {
@@ -959,10 +1024,10 @@ sub api {
             [ {}, "_optimize" ]
         ],
         qs => [
-            "allow_no_indices", "expand_wildcards",
-            "flush",            "ignore_unavailable",
-            "max_num_segments", "only_expunge_deletes",
-            "wait_for_merge",
+            "allow_no_indices",     "expand_wildcards",
+            "flush",                "force",
+            "ignore_unavailable",   "max_num_segments",
+            "only_expunge_deletes", "wait_for_merge",
         ],
     },
 
@@ -1045,6 +1110,16 @@ sub api {
         ],
     },
 
+    'indices.recovery' => {
+        doc   => "indices-recovery",
+        parts => { index => { multi => 1 } },
+        paths => [
+            [ { index => 0 }, "{index}", "_recovery" ],
+            [ {}, "_recovery" ]
+        ],
+        qs => [ "active_only", "detailed", "human" ],
+    },
+
     'indices.refresh' => {
         doc    => "indices-refresh",
         method => "POST",
@@ -1305,6 +1380,24 @@ sub api {
         qs => [ "master_timeout", "wait_for_completion" ],
     },
 
+    'snapshot.status' => {
+        doc   => "modules-snapshots",
+        parts => { repository => {}, snapshot => { multi => 1 } },
+        paths => [
+            [   { repository => 1, snapshot => 2 }, "_snapshot",
+                "{repository}", "{snapshot}",
+                "_status",
+            ],
+            [   { snapshot => 2 }, "_snapshot",
+                "_all", "{snapshot}",
+                "_status"
+            ],
+            [ { repository => 1 }, "_snapshot", "{repository}", "_status" ],
+            [ {}, "_snapshot", "_status" ],
+        ],
+        qs => ["master_timeout"],
+    },
+
 #=== AUTOGEN - END ===
 
 );
@@ -1325,7 +1418,7 @@ Search::Elasticsearch::Role::API - This class contains the spec for the Elastics
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 DESCRIPTION
 
