@@ -1,13 +1,37 @@
 package Search::Elasticsearch::Role::CxnPool::Static::NoPing;
-$Search::Elasticsearch::Role::CxnPool::Static::NoPing::VERSION = '1.10';
+$Search::Elasticsearch::Role::CxnPool::Static::NoPing::VERSION = '1.11';
 use Moo::Role;
 with 'Search::Elasticsearch::Role::CxnPool';
-requires 'next_cxn';
+
 use namespace::clean;
 
 has 'max_retries' => ( is => 'lazy' );
 has '_dead_cxns' => ( is => 'ro', default => sub { [] } );
 
+#===================================
+sub next_cxn {
+#===================================
+    my $self = shift;
+
+    my $cxns  = $self->cxns;
+    my $total = @$cxns;
+    my $dead  = $self->_dead_cxns;
+
+    while ( $total-- ) {
+        my $cxn = $cxns->[ $self->next_cxn_num ];
+        return $cxn
+            if $cxn->is_live
+            || $cxn->next_ping < time();
+        push @$dead, $cxn unless grep { $_ eq $cxn } @$dead;
+    }
+
+    if ( @$dead and $self->retries <= $self->max_retries ) {
+        $_->force_ping for @$dead;
+        return shift @$dead;
+    }
+    throw( "NoNodes", "No nodes are available: [" . $self->cxns_str . ']' );
+}
+
 #===================================
 sub _build_max_retries { @{ shift->cxns } - 1 }
 sub _max_retries       { shift->max_retries + 1 }
@@ -55,26 +79,7 @@ Search::Elasticsearch::Role::CxnPool::Static::NoPing - A CxnPool for connecting
 
 =head1 VERSION
 
-version 1.10
-
-=head1 CONFIGURATION
-
-=head2 C<max_retries>
-
-The number of times a request should be retried before throwin an exception.
-Defaults to the number of nodes minus 1.
-
-=head1 METHODS
-
-=head2 C<should_mark_dead()>
-
-    $bool = $cxn_pool->should_mark_dead($error);
-
-Connection and timeout errors cause cxns to be marked as dead.
-
-=head2 C<schedule_check()>
-
-This method is a NOOP.
+version 1.11
 
 =head1 AUTHOR
 
