@@ -1,23 +1,24 @@
 package Search::Elasticsearch::Role::Scroll;
-$Search::Elasticsearch::Role::Scroll::VERSION = '1.10';
+$Search::Elasticsearch::Role::Scroll::VERSION = '1.11';
 use Moo::Role;
-requires 'finish';
+requires '_clear_scroll';
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Scalar::Util qw(weaken blessed);
 use namespace::clean;
 
 has 'es' => ( is => 'ro', required => 1 );
-has 'scroll'        => ( is => 'ro' );
-has 'total'         => ( is => 'rwp' );
-has 'max_score'     => ( is => 'rwp' );
-has 'facets'        => ( is => 'rwp' );
-has 'aggregations'  => ( is => 'rwp' );
-has 'suggest'       => ( is => 'rwp' );
-has 'took'          => ( is => 'rwp' );
-has 'total_took'    => ( is => 'rwp' );
-has 'search_params' => ( is => 'ro' );
-has 'is_finished'   => ( is => 'rwp', default => '' );
-has '_scroll_id'    => ( is => 'rwp', clearer => 1, predicate => 1 );
+has 'scroll'         => ( is => 'ro' );
+has 'scroll_in_body' => ( is => 'ro' );
+has 'total'          => ( is => 'rwp' );
+has 'max_score'      => ( is => 'rwp' );
+has 'facets'         => ( is => 'rwp' );
+has 'aggregations'   => ( is => 'rwp' );
+has 'suggest'        => ( is => 'rwp' );
+has 'took'           => ( is => 'rwp' );
+has 'total_took'     => ( is => 'rwp' );
+has 'search_params'  => ( is => 'ro' );
+has 'is_finished'    => ( is => 'rwp', default => '' );
+has '_scroll_id'     => ( is => 'rwp', clearer => 1, predicate => 1 );
 
 #===================================
 sub finish {
@@ -25,10 +26,23 @@ sub finish {
     my $self = shift;
     return if $self->is_finished;
     $self->_set_is_finished(1);
+    $self->_clear_scroll;
+}
 
-    my $scroll_id = $self->_scroll_id or return;
-    $self->_clear_scroll_id;
-    eval { $self->es->clear_scroll( scroll_id => $scroll_id ) };
+
+
+#===================================
+sub scroll_request {
+#===================================
+    my $self = shift;
+    my %args = ( scroll => $self->scroll );
+    if ( $self->scroll_in_body ) {
+        $args{body} = $self->_scroll_id;
+    }
+    else {
+        $args{scroll_id} = $self->_scroll_id;
+    }
+    $self->es->scroll(%args);
 }
 
 #===================================
@@ -54,7 +68,7 @@ Search::Elasticsearch::Role::Scroll - Provides common functionality to L<Elastic
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 AUTHOR
 
