@@ -1,5 +1,5 @@
 package Search::Elasticsearch::TestServer;
-$Search::Elasticsearch::TestServer::VERSION = '1.10';
+$Search::Elasticsearch::TestServer::VERSION = '1.11';
 use Moo;
 use Search::Elasticsearch();
 use POSIX 'setsid';
@@ -98,7 +98,7 @@ sub _start_node {
         if ( $pid == 0 ) {
             throw( 'Internal', "Can't start a new session: $!" )
                 if setsid == -1;
-            exec(@config);
+            exec(@config) or die "Couldn't execute @config: $!";
         }
         else {
             for ( 1 .. 5 ) {
@@ -107,7 +107,7 @@ sub _start_node {
             }
             open my $pid_fh, '<', $pid_file->filename;
             my $pid = <$pid_fh>;
-            throw( 'Internal', "ES is running, but no PID found" )
+            throw( 'Internal', "No PID file found for Elasticsearch" )
                 unless $pid;
             chomp $pid;
             push @{ $self->{pids} }, $pid;
@@ -148,6 +148,7 @@ sub _command_line {
             'discovery.zen.ping.unicast.hosts=127.0.0.1:' . $self->es_port,
             'transport.tcp.port=' . $transport,
             'http.port=' . $http,
+            'node.bench=true'
         )
     );
 }
@@ -172,7 +173,7 @@ Search::Elasticsearch::TestServer - A helper class to launch Elasticsearch nodes
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
