@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Util::API::QS;
-$Search::Elasticsearch::Util::API::QS::VERSION = '1.10';
+$Search::Elasticsearch::Util::API::QS::VERSION = '1.11';
 use strict;
 use warnings;
 
@@ -20,6 +20,7 @@ our %Handler = (
 );
 
 our %Params = (
+    active_only      => { type => 'bool' },
     all              => { type => 'bool' },
     allow_no_indices => { type => 'bool' },
     analyze_wildcard => { type => 'bool' },
@@ -39,6 +40,7 @@ our %Params = (
         type    => 'enum'
     },
     delay            => { type => 'duration' },
+    detailed         => { type => 'bool' },
     df               => { type => 'string' },
     docs             => { type => 'bool' },
     dry_run          => { type => 'bool' },
@@ -205,6 +207,7 @@ our %Params = (
     type            => { type => 'string' },
     types           => { type => 'list' },
     v               => { type => 'bool' },
+    verbose         => { type => 'bool' },
     version         => { type => 'number' },
     version_type    => {
         type    => 'enum',
@@ -249,7 +252,7 @@ Search::Elasticsearch::Util::API::QS - A utility class for query string paramete
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 DESCRIPTION
 
